# Contribution Guidelines

Thank you for considering contributing to our project! We appreciate your interest and support. By contributing, you can help us improve the project and make it better for everyone. Please take a moment to review these guidelines before getting started.

## How Can You Contribute?

There are several ways you can contribute to this project:

1. **Reporting Bugs:** If you encounter any bugs or issues with the project, please open a new issue on our [Issue Tracker](https://github.com/SINTEF/paraspace/issues).

2. **Suggesting Enhancements:** If you have ideas for enhancements or new features, feel free to create an issue to discuss them.

3. **Code Contributions:** We welcome code contributions. If you want to fix a bug or work on a new feature, follow the steps below.

## How to Contribute Code

1. **Fork the Repository:** Click the "Fork" button on the top right of this repository. This creates a copy of the project in your GitHub account.
2. **Clone Your Fork:** Clone your forked repository to your local machine using `git clone`.
3. **Create a new branch:** Create a new brach for your work. Choose a descriptive name that reflects the purpose of your changes
4. **Make your changes:** Make your changes and improvements locally and push to your fork.
5. **Open a Pull Request:** Open a pull request to the paraspace repo with a description of the purpose of your suggested changes.
6. **Review and Merge:** Participate in eventual discussions of the pull request and adress any comments from maintainers. Once your changes are approved a project maintainer will merge you pull request into the main branch.

## Guidelines for Participation
When contributing either through issues or pull requests, we encourage you to describe the discovered bug, the suggested code alterations and new code as thorughly as possible.
For bugs, espeically, please include error messages, logs and example code to recreate the error.

## License
By contributing to this project, you agree that your contributions will be licened under the project's licence (See LICENCE file)
